=======================
Account LInking SErvice
=======================

Tool to link accounts 

Documentation
-------------

.. toctree::
   :maxdepth: 1

   alise/installation
   alise/development


Reporting Bugs
--------------

Issues are managed at `github <https://github.com/marcvs/alise/issues/>`_.



API Reference
-------------

If you are looking for information on a specific function, class or
method, this part of the documentation is for you.

.. toctree::
   :maxdepth: 2

   alise/api/index

-----------------


Indices
=======

* :ref:`genindex`
* :ref:`modindex`
